Module assembler

Module assembler 

Jena Assembler vocabulary support.

This module allows users migrating from Apache Jena to use their existing fuseki-config.ttl assembler files with OxiRS. A Jena assembler document uses the ja: namespace (http://jena.hpl.hp.com/2005/11/Assembler#) to describe datasets, named graphs, and storage backends in RDF/Turtle format.

Quick start

use oxirs_core::assembler;

let ttl = r#"
    @prefix ja: <http://jena.hpl.hp.com/2005/11/Assembler#> .
    <http://example.org/ds> a ja:RDFDataset .
"#;
let config = assembler::from_turtle(ttl).unwrap();
assert_eq!(config.len(), 1);

Supported vocabulary

TermDescription
ja:RDFDatasetGeneric RDF dataset
ja:MemoryDatasetIn-memory dataset
ja:MemoryModelIn-memory RDF model
tdb2:DatasetTDB2TDB2 disk-backed dataset
ja:namedGraphNamed-graph description
ja:graphNameIRI of a named graph
ja:graphModel resource for a named graph
ja:defaultGraphDefault-graph model resource
ja:contentURLURL to load initial RDF content
tdb2:locationFilesystem path for TDB2 storage

Re-exports

pub use builder::AssemblerBuilder;
pub use builder::AssemblerError;
pub use config::AssemblerConfig;
pub use config::DatasetConfig;
pub use config::GraphConfig;
pub use config::StoreBackend;

Modules

builder
Jena Assembler document parser.
config
Configuration types produced by the Jena Assembler parser.
vocab
Jena Assembler vocabulary constants.

Functions

from_turtle
Parse a Turtle-format Jena Assembler document into an AssemblerConfig.