pub struct CoreCacheEntry {
pub key: CoreCacheKey,
pub result_rows: Vec<HashMap<String, String>>,
pub accessed_predicates: Vec<String>,
pub created_at: Instant,
pub last_accessed: Instant,
pub expires_at: Instant,
pub hit_count: u64,
}Expand description
An individual entry in the result cache.
Fields
key: CoreCacheKeyComposite key that identifies this entry.
result_rows: Vec<HashMap<String, String>>Cached result rows (variable bindings).
accessed_predicates: Vec<String>Predicate IRIs that the cached query accessed. Used for targeted invalidation.
created_at: InstantWhen this entry was stored.
last_accessed: InstantWhen this entry was last read.
expires_at: InstantEntry becomes invalid after this instant.
hit_count: u64Number of times this entry has been served from the cache.
Implementations
Sourceimpl CoreCacheEntry
impl CoreCacheEntry
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Return true if this entry has passed its TTL.