pub struct IdentifierIssuer { /* private fields */ }Expand description
Issues monotonically increasing canonical blank node identifiers.
Each call to IdentifierIssuer::issue either returns the previously
assigned identifier for a blank node or mints a fresh one with the format
_:c14n<N>. The internal counter starts at 0.
Implementations
Sourceimpl IdentifierIssuer
impl IdentifierIssuer
Sourcepub fn new(prefix: impl Into<String>) -> Self
pub fn new(prefix: impl Into<String>) -> Self
Create a new issuer using prefix as the canonical identifier prefix.
Sourcepub fn issue(&mut self, original: &str) -> String
pub fn issue(&mut self, original: &str) -> String
Return the canonical identifier that has been (or will be) assigned to
original. If this is the first call for original, a new identifier
is minted.
Sourcepub fn get(&self, original: &str) -> Option<&str>
pub fn get(&self, original: &str) -> Option<&str>
Return the canonical identifier for original if it has already been
issued, without minting a new one.
Sourcepub fn has_issued(&self, original: &str) -> bool
pub fn has_issued(&self, original: &str) -> bool
Return true if a canonical identifier has already been issued for
original.
Sourcepub fn issued_pairs(&self) -> impl Iterator<Item = (&str, &str)>
pub fn issued_pairs(&self) -> impl Iterator<Item = (&str, &str)>
Return an iterator over (original, canonical) pairs in issue order.