pub struct PostProcessingWriter<W: Write> { /* private fields */ }Expand description
A Write adapter that buffers all output in memory so it can be
re-sorted (line-wise) and/or re-terminated with a custom line ending
before being flushed to the wrapped writer on finalize.