pub enum JsonLdValue {
Null,
Bool(bool),
Number(f64),
Str(String),
Array(Vec<JsonLdValue>),
Object(IndexMap<String, JsonLdValue>),
}Expand description
A JSON-LD value that can appear in an expanded or compact JSON-LD document.
Uses IndexMap for objects to maintain insertion order (required by JSON-LD spec).
Variants
Null
JSON null.
Bool(bool)
JSON boolean.
Number(f64)
JSON number.
Str(String)
JSON string.
Array(Vec<JsonLdValue>)
JSON array.
Object(IndexMap<String, JsonLdValue>)
JSON object with insertion-ordered keys.
Implementations
Sourceimpl JsonLdValue
impl JsonLdValue
Sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Returns the string value if this is a Str, otherwise None.
Sourcepub fn as_object(&self) -> Option<&IndexMap<String, JsonLdValue>>
pub fn as_object(&self) -> Option<&IndexMap<String, JsonLdValue>>
Returns the object map if this is an Object, otherwise None.
Sourcepub fn as_array(&self) -> Option<&[JsonLdValue]>
pub fn as_array(&self) -> Option<&[JsonLdValue]>
Returns the array if this is an Array, otherwise None.
Sourcepub fn into_array_if_not(self) -> Vec<JsonLdValue>
pub fn into_array_if_not(self) -> Vec<JsonLdValue>
Wraps a value in a single-element array.