pub struct TermDefinition {
pub iri_mapping: Option<String>,
pub prefix_flag: bool,
pub protected: bool,
pub reverse_property: bool,
pub container: Vec<ContainerType>,
pub language: Option<String>,
pub direction: Option<String>,
pub nest: Option<String>,
pub type_mapping: Option<String>,
}Expand description
Definition of a single term in the active context.
Corresponds to a JSON-LD term definition as specified in 4.1.
Fields
iri_mapping: Option<String>The expanded IRI mapping for this term.
prefix_flag: boolWhether this term can be used as a prefix.
protected: boolWhether this term definition is protected.
reverse_property: boolWhether this is a reverse property.
container: Vec<ContainerType>Container types for the term’s values.
language: Option<String>Default language for the term’s values.
direction: Option<String>Default text direction for the term’s values.
nest: Option<String>Nest value for the term.
type_mapping: Option<String>Type mapping for the term.
Implementations