pub struct QueryStats {
pub query_hash: u64,
pub actual_rows: usize,
pub estimated_rows: usize,
pub execution_time_ms: u64,
pub join_order: Vec<String>,
pub selectivity_by_pattern: HashMap<String, f64>,
}Expand description
Statistics recorded for a single query execution.
Fields
query_hash: u64Hash of the query string (see AdaptiveQueryOptimizer::hash_query).
actual_rows: usizeNumber of rows actually produced.
estimated_rows: usizeNumber of rows the optimizer estimated would be produced.
execution_time_ms: u64Wall-clock time consumed by the execution, in milliseconds.
join_order: Vec<String>The join order that was used, as a list of pattern descriptions.
selectivity_by_pattern: HashMap<String, f64>Per-pattern selectivities observed during execution.
Implementations
Sourceimpl QueryStats
impl QueryStats
Sourcepub fn new(
query_hash: u64,
actual_rows: usize,
estimated_rows: usize,
execution_time_ms: u64,
join_order: Vec<String>,
selectivity_by_pattern: HashMap<String, f64>,
) -> Self
pub fn new( query_hash: u64, actual_rows: usize, estimated_rows: usize, execution_time_ms: u64, join_order: Vec<String>, selectivity_by_pattern: HashMap<String, f64>, ) -> Self
Construct a new QueryStats value.
Sourcepub fn accuracy_ratio(&self) -> f64
pub fn accuracy_ratio(&self) -> f64
Ratio of actual to estimated rows. Returns 1.0 when no estimate exists.