pub struct Parser { /* private fields */ }Expand description
RDF parser interface
Implementations
Sourceimpl Parser
impl Parser
Sourcepub fn with_config(format: RdfFormat, config: ParserConfig) -> Self
pub fn with_config(format: RdfFormat, config: ParserConfig) -> Self
Create a parser with custom configuration
Sourcepub fn with_base_iri(self, base_iri: impl Into<String>) -> Self
pub fn with_base_iri(self, base_iri: impl Into<String>) -> Self
Set the base IRI for resolving relative IRIs
Sourcepub fn with_error_tolerance(self, ignore_errors: bool) -> Self
pub fn with_error_tolerance(self, ignore_errors: bool) -> Self
Enable or disable error tolerance
Sourcepub fn parse_str_to_quads(&self, data: &str) -> Result<Vec<Quad>>
pub fn parse_str_to_quads(&self, data: &str) -> Result<Vec<Quad>>
Parse RDF data from a string into a vector of quads
Sourcepub fn parse_str_to_triples(&self, data: &str) -> Result<Vec<Triple>>
pub fn parse_str_to_triples(&self, data: &str) -> Result<Vec<Triple>>
Parse RDF data from a string into a vector of triples (only default graph)
Sourcepub fn parse_str_with_handler<F>(&self, data: &str, handler: F) -> Result<()>
pub fn parse_str_with_handler<F>(&self, data: &str, handler: F) -> Result<()>
Parse RDF data with a custom handler for each quad
pub fn parse_ntriples_line(&self, line: &str) -> Result<Option<Quad>>
pub fn parse_nquads_line(&self, line: &str) -> Result<Option<Quad>>