pub struct DiffStats {
pub added_count: usize,
pub removed_count: usize,
pub unchanged_count: usize,
}Expand description
Statistics about a diff operation.
Fields
added_count: usizeNumber of triples present in after but not in before.
removed_count: usizeNumber of triples present in before but not in after.
unchanged_count: usizeNumber of triples present in both datasets (unchanged).