pub struct TokenStream { /* private fields */ }Expand description
An immutable, cloneable view of a token stream with a cursor position
Implementations
Sourceimpl TokenStream
impl TokenStream
Sourcepub fn next(self) -> (Option<Token>, TokenStream)
pub fn next(self) -> (Option<Token>, TokenStream)
Consume the current token, returning it and the advanced stream
Sourcepub fn byte_offset(&self) -> usize
pub fn byte_offset(&self) -> usize
Return the byte offset of the current token (or end-of-source)