pub struct SubqueryOptimizer;Expand description
Pushes FILTER expressions inside subqueries when safe to do so.
A filter is “safe” to push down into an inner Select subquery when every
variable referenced by the filter is projected by (i.e. available from) the
inner subquery.
Implementations
Sourceimpl SubqueryOptimizer
impl SubqueryOptimizer
Sourcepub fn optimize(&self, node: SubqueryNode) -> SubqueryNode
pub fn optimize(&self, node: SubqueryNode) -> SubqueryNode
Optimize node by pushing filters inward.