pub async fn create_engine(
config: StorageConfig,
) -> Result<Arc<dyn StorageEngine>, OxirsError>Expand description
Create a new storage engine with the given configuration
pub async fn create_engine(
config: StorageConfig,
) -> Result<Arc<dyn StorageEngine>, OxirsError>Create a new storage engine with the given configuration