pub struct ReadOnlyMmapView { /* private fields */ }Expand description
Read-only view of a memory-mapped triple store
This allows safe concurrent read access to the underlying data without requiring locks.
Implementations
Sourceimpl ReadOnlyMmapView
impl ReadOnlyMmapView
Sourcepub fn get_raw_triple(&self, index: usize) -> Option<&[u8]>
pub fn get_raw_triple(&self, index: usize) -> Option<&[u8]>
Get raw bytes for a triple at the given index