pub enum QuadEncoding {
Spog,
Posg,
Ospg,
Gspo,
Gpos,
Gosp,
}Expand description
Quad encoding variations for different sort orders
Variants
Spog
Subject, Predicate, Object, Graph
Posg
Predicate, Object, Subject, Graph
Ospg
Object, Subject, Predicate, Graph
Gspo
Graph, Subject, Predicate, Object
Gpos
Graph, Predicate, Object, Subject
Gosp
Graph, Object, Subject, Predicate
Implementations
Sourceimpl QuadEncoding
impl QuadEncoding
Sourcepub fn decode(self, buffer: &[u8]) -> Result<EncodedQuad, OxirsError>
pub fn decode(self, buffer: &[u8]) -> Result<EncodedQuad, OxirsError>
Decodes a quad from a buffer according to this encoding
Sourcepub fn encode(
self,
quad: &EncodedQuad,
buffer: &mut Vec<u8>,
) -> Result<(), OxirsError>
pub fn encode( self, quad: &EncodedQuad, buffer: &mut Vec<u8>, ) -> Result<(), OxirsError>
Encodes a quad to a buffer according to this encoding