StrHash

Struct StrHash 

pub struct StrHash { /* private fields */ }
A hash of a string for efficient storage and comparison

Implementations

Source

impl StrHash

pub fn new(value: &str) -> Self

Creates a new string hash using a fast hashing algorithm

pub fn from_be_bytes(hash: [u8; 16]) -> Self

Creates a StrHash from raw bytes

pub fn to_be_bytes(self) -> [u8; 16]

Returns the hash as raw bytes