pub struct GraphView {
pub name: String,
pub base_iri: Option<String>,
/* private fields */
}Expand description
A read-only, named view over a set of RDF triples.
Conceptually represents a named graph in an RDF dataset. The view holds an owned snapshot of the triples (or references to an external store via index).
Fields
name: StringName / IRI of this graph view.
base_iri: Option<String>Optional base IRI for relative IRI resolution.
Implementations
Sourceimpl GraphView
impl GraphView
Sourcepub fn new(name: &str, triples: Vec<RdfTriple>) -> Self
pub fn new(name: &str, triples: Vec<RdfTriple>) -> Self
Create a new named graph view with the given triples.
Sourcepub fn with_base_iri(self, base: &str) -> Self
pub fn with_base_iri(self, base: &str) -> Self
Set the base IRI for this view.
pub fn is_empty(&self) -> bool
Sourcepub fn find(
&self,
subject: Option<&str>,
predicate: Option<&str>,
object: Option<&str>,
) -> Vec<&RdfTriple>
pub fn find( &self, subject: Option<&str>, predicate: Option<&str>, object: Option<&str>, ) -> Vec<&RdfTriple>
Find all triples matching the given triple pattern. None = wildcard.
Sourcepub fn predicates(&self) -> Vec<&str>
pub fn predicates(&self) -> Vec<&str>
All distinct predicates in this view.
Sourcepub fn filter(
&self,
subject: Option<String>,
predicate: Option<String>,
object: Option<String>,
) -> FilteredView
pub fn filter( &self, subject: Option<String>, predicate: Option<String>, object: Option<String>, ) -> FilteredView
Create a FilteredView over this view.