pub struct Dataset { /* private fields */ }Expand description
An in-memory RDF Dataset
A dataset is a collection of named graphs plus a default graph. Each named graph is identified by an IRI or blank node.
Implementations
Sourceimpl Dataset
impl Dataset
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new dataset with the specified capacity for named graphs
Sourcepub fn default_graph(&self) -> &Graph
pub fn default_graph(&self) -> &Graph
Returns a reference to the default graph
Sourcepub fn default_graph_mut(&mut self) -> &mut Graph
pub fn default_graph_mut(&mut self) -> &mut Graph
Returns a mutable reference to the default graph
Sourcepub fn named_graph(&self, name: &GraphName) -> Option<&Graph>
pub fn named_graph(&self, name: &GraphName) -> Option<&Graph>
Returns a reference to the named graph with the given name
Sourcepub fn named_graph_mut(&mut self, name: &GraphName) -> &mut Graph
pub fn named_graph_mut(&mut self, name: &GraphName) -> &mut Graph
Returns a mutable reference to the named graph with the given name
Creates the graph if it doesn’t exist.
Sourcepub fn insert(&mut self, quad: Quad) -> bool
pub fn insert(&mut self, quad: Quad) -> bool
Inserts a quad into the dataset
Returns true if the quad was not already present, false otherwise.
Sourcepub fn remove(&mut self, quad: &Quad) -> bool
pub fn remove(&mut self, quad: &Quad) -> bool
Removes a quad from the dataset
Returns true if the quad was present, false otherwise.
Sourcepub fn contains(&self, quad: &Quad) -> bool
pub fn contains(&self, quad: &Quad) -> bool
Returns true if the dataset contains the specified quad
Sourcepub fn named_graph_count(&self) -> usize
pub fn named_graph_count(&self) -> usize
Returns the number of named graphs (excluding default graph)
Sourcepub fn graph_names(&self) -> impl Iterator<Item = &GraphName>
pub fn graph_names(&self) -> impl Iterator<Item = &GraphName>
Returns an iterator over all graph names (excluding default graph)
Sourcepub fn named_graphs(&self) -> impl Iterator<Item = (&GraphName, &Graph)>
pub fn named_graphs(&self) -> impl Iterator<Item = (&GraphName, &Graph)>
Returns an iterator over all named graphs
Sourcepub fn remove_graph(&mut self, name: &GraphName) -> Option<Graph>
pub fn remove_graph(&mut self, name: &GraphName) -> Option<Graph>
Removes a named graph from the dataset
Returns the removed graph if it existed.
Sourcepub fn iter(&self) -> impl Iterator<Item = Quad> + '_
pub fn iter(&self) -> impl Iterator<Item = Quad> + '_
Returns an iterator over all quads in the dataset
Sourcepub fn iter_ref(&self) -> impl Iterator<Item = QuadRef<'_>> + '_
pub fn iter_ref(&self) -> impl Iterator<Item = QuadRef<'_>> + '_
Returns an iterator over all quads in the dataset as references
Sourcepub fn quads_for_pattern<'a>(
&'a self,
subject: Option<&'a Subject>,
predicate: Option<&'a Predicate>,
object: Option<&'a Object>,
graph_name: Option<&'a GraphName>,
) -> Box<dyn Iterator<Item = Quad> + 'a>
pub fn quads_for_pattern<'a>( &'a self, subject: Option<&'a Subject>, predicate: Option<&'a Predicate>, object: Option<&'a Object>, graph_name: Option<&'a GraphName>, ) -> Box<dyn Iterator<Item = Quad> + 'a>
Finds all quads matching the given pattern
None values in the pattern act as wildcards.
Sourcepub fn extend<I>(&mut self, quads: I)where
I: IntoIterator<Item = Quad>,
pub fn extend<I>(&mut self, quads: I)where
I: IntoIterator<Item = Quad>,
Extends the dataset with quads from an iterator