pub struct BlankNode { /* private fields */ }Expand description
A blank node identifier
Blank nodes are local identifiers used in RDF graphs that don’t have global meaning. Supports both named identifiers and efficient numerical IDs.
Implementations
Sourceimpl BlankNode
impl BlankNode
Sourcepub fn new_unchecked(id: impl Into<String>) -> Self
pub fn new_unchecked(id: impl Into<String>) -> Self
Creates a new blank node without validation
Safety
The caller must ensure the ID is valid and properly formatted
Sourcepub fn new_from_unique_id(id: u128) -> Self
pub fn new_from_unique_id(id: u128) -> Self
Creates a blank node from a unique numerical id.
In most cases, it is much more convenient to create a blank node using BlankNode::default().
Sourcepub fn new_unique() -> Self
pub fn new_unique() -> Self
Generates a new unique blank node with collision detection
This method ensures global uniqueness across all threads and sessions
Sourcepub fn new_unique_with_prefix(prefix: &str) -> Result<Self, OxirsError>
pub fn new_unique_with_prefix(prefix: &str) -> Result<Self, OxirsError>
Generates a new unique blank node with a custom prefix
Sourcepub fn unique_id(&self) -> Option<u128>
pub fn unique_id(&self) -> Option<u128>
Returns the internal numerical ID of this blank node if it has been created using BlankNode::new_from_unique_id or BlankNode::default.
Sourcepub fn as_ref(&self) -> BlankNodeRef<'_>
pub fn as_ref(&self) -> BlankNodeRef<'_>
Returns a reference to this BlankNode as a BlankNodeRef